@@ -3,6 +3,3 @@
 
 class ConfigBaseError(Exception):
     """The base autoconfiguration exception."""
-
-    def __init__(self, message: str):
-        super().__init__(message)
